/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.obs.ant.tasks;

import java.net.MalformedURLException;
import java.util.Arrays;
import java.util.HashSet;
import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Project;
import org.apache.tools.ant.Task;
import com.openexchange.obs.api.BuildServiceClient;
import com.openexchange.obs.api.BuildServiceException;
import com.openexchange.obs.api.ObsPackage;

/**
 * Checks the package names already on OBS and compares them to a given list. Will delete not needed packages Seperator of given list is ","
 * 
 * @author <a href="mailto:felix.marx@open-xchange.com">Felix Marx</a>
 */
public final class GetPackageList extends Task {

    private String url;

    private String login;

    private String password;

    private String projectName;

    private String property;
    
    private String delimiter;

    public GetPackageList() {
        super();
    }

    public void setUrl(final String url) {
        this.url = url;
    }

    public void setLogin(final String login) {
        this.login = login;
    }

    public void setPassword(final String password) {
        this.password = password;
    }

    public void setProjectName(final String projectName) {
        this.projectName = projectName;
    }

    public void setProperty(final String property) {
        this.property = property;
    }
    
    public void setDelimiter(final String delimiter) {
        this.delimiter = delimiter;
    }

    @Override
    public void execute() throws BuildException {
        if (projectName == null) {
            throw new BuildException("Please define project.");
        }
        if (property == null) {
            throw new BuildException("Please define packageNamesProperty.");
        }
        
        if (delimiter == null) {
            log("No delimiter is set, will use \",\" ", Project.MSG_ERR);
            delimiter = ",";
        }

        final BuildServiceClient bsc;
        try {
            bsc = new BuildServiceClient(url, login, password);
            final ObsPackage[] packages = bsc.getPackageList(projectName);

            final HashSet<String> currentPackages = new HashSet<String>();
            // creates intersect list of packageNames in this project and the given list of packageNames
            String packagesNamesString = "";
            for (ObsPackage obsp : bsc.getPackageList(projectName)) {
                packagesNamesString = packagesNamesString + obsp.getPackageName() + delimiter;
            }
            
            System.out.println(property + " => " + packagesNamesString);
            getProject().setInheritedProperty(property , packagesNamesString);

        } catch (final MalformedURLException e) {
            throw new BuildException(e.getMessage(), e);
        } catch (final BuildServiceException e) {
            throw new BuildException(e.getMessage(), e);
        }

    }
}
